@@ -87,12 +87,9 @@ KComputer::KComputer()
   mBrainUsed   = 0;
 
   // Connect signals of KGame framework
-  connect(&proc,SIGNAL(signalCommand(QDataStream&,int,int,int)),
-                   this,SLOT(slotCommand(QDataStream&,int,int,int)));
-  connect(&proc,SIGNAL(signalInit(QDataStream&,int)),
-                   this,SLOT(slotInit(QDataStream&,int)));
-  connect(&proc,SIGNAL(signalTurn(QDataStream&,bool)),
-                   this,SLOT(slotTurn(QDataStream&,bool)));
+  connect(&proc, &KGameProcess::signalCommand, this, &KComputer::slotCommand);
+  connect(&proc, &KGameProcess::signalInit, this, &KComputer::slotInit);
+  connect(&proc, &KGameProcess::signalTurn, this, &KComputer::slotTurn);
 }
 
 
@@ -700,4 +697,4 @@ int main(int argc ,char * argv[])
   fflush(stderr);
   return 1;
 }
-#include "kwin4proc.moc"
+
